@@ -3,12 +3,16 @@ Copyright Amazon.com, Inc. or its affiliates. All Rights Reserved.
 SPDX-License-Identifier: Apache-2.0
 """
 
+
 class DefaultRequestGenerator(object):
     @staticmethod
     def generate_request_params(method, action, query, host, port, protocol, headers=None):
-        return {
+        url = f'{protocol}://{host}:{port}/{action}' if port != '' else f'{protocol}://{host}/{action}'
+        params = {
             'method': method,
-            'url': f'{protocol}://{host}:{port}/{action}',
+            'url': url,
             'headers': headers,
             'params': query,
         }
+
+        return params
