@@ -34,7 +34,9 @@ def query_type_to_action(query_type):
         return 'sparqlupdate'
 
 
-def do_sparql_query(query, host, port, use_ssl, request_param_generator, extra_headers=None, path_prefix: str = ''):
+def do_sparql_query(query, host, port, use_ssl, request_param_generator, extra_headers=None, path: str = SPARQL_ACTION):
+    path = SPARQL_ACTION if path == '' else path
+
     if extra_headers is None:
         extra_headers = {}
     logger.debug(f'query={query}, endpoint={host}, port={port}')
@@ -47,8 +49,7 @@ def do_sparql_query(query, host, port, use_ssl, request_param_generator, extra_h
     elif action == 'sparqlupdate':
         data['update'] = query
 
-    sparql_path = SPARQL_ACTION if path_prefix == '' else f'{path_prefix}/{SPARQL_ACTION}'
-    res = call_and_get_response('post', sparql_path, host, port, request_param_generator, use_ssl, data, extra_headers)
+    res = call_and_get_response('post', path, host, port, request_param_generator, use_ssl, data, extra_headers)
     try:
         content = res.json()  # attempt to return json, otherwise we will return the content string.
     except Exception:
@@ -57,7 +58,9 @@ def do_sparql_query(query, host, port, use_ssl, request_param_generator, extra_h
 
 
 def do_sparql_explain(query: str, host: str, port: str, use_ssl: bool, request_param_generator,
-                      accept_type='text/html', path_prefix: str = ''):
+                      accept_type='text/html', path: str = ''):
+    path = SPARQL_ACTION if path == '' else path
+
     query_type = get_query_type(query)
     action = query_type_to_action(query_type)
 
@@ -74,7 +77,6 @@ def do_sparql_explain(query: str, host: str, port: str, use_ssl: bool, request_p
         'Accept': accept_type
     }
 
-    sparql_path = SPARQL_ACTION if path_prefix == '' else f'{path_prefix}/{SPARQL_ACTION}'
-    res = call_and_get_response('post', sparql_path, host, port, request_param_generator, use_ssl, data,
+    res = call_and_get_response('post', path, host, port, request_param_generator, use_ssl, data,
                                 extra_headers)
     return res.content.decode('utf-8')
